@@ -1,4 +1,9 @@
 from .networking import epoll, EPOLLIN, EPOLLHUP
+from .networking import generate_mac
+from .qemu.environment import load_network_cards_from_env as load_network_cards_from_env
+from .qemu.environment import load_conf as load_conf
+from .qemu.environment import load_environment as load_environment
+from .qemu.environment import dismantle_environment as dismantle_environment
 from .helpers import DupeDict as DupeDict
 from .helpers import JsonEncoder as JsonEncoder
 from .helpers import JSON as JSON
