@@ -11,8 +11,11 @@ from .net import ifup as ifup
 from .net import ifdown as ifdown
 from .net import get_namespace_info as get_namespace_info
 from .net import get_interface_info as get_interface_info
+from .net import create_interface as create_interface
 from .net import load_network_info as load_network_info
 from .net import unload_network_info as unload_network_info
+from .interfaces import generate_mac as generate_mac
+from .interfaces import get_bridge_interfaces as get_bridge_interfaces
 
 __all__ = [
 	"epoll",
@@ -28,6 +31,9 @@ __all__ = [
 	"ifdown",
 	"get_namespace_info",
 	"get_interface_info",
+	"create_interface",
 	"load_network_info",
-	"unload_network_info"
+	"unload_network_info",
+	"generate_mac",
+	"get_bridge_interfaces"
 ]
\ No newline at end of file
